#[non_exhaustive]pub enum EffectClass {
Pure,
ReadOnly,
IdempotentWrite,
NonIdempotentWrite,
Destructive,
Unknown,
}Expand description
The external-effect behavior of a capability.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pure
No externally visible effect.
ReadOnly
Reads external state without modifying it.
IdempotentWrite
Writes external state and is safe to repeat with the same key.
NonIdempotentWrite
Writes external state and may not be safe to repeat.
Destructive
May destroy or irreversibly mutate state.
Unknown
Effect behavior is unknown.