#[non_exhaustive]pub enum RetrySafety {
Safe,
RequiresIdempotency,
UnsafeAfterVisibleOutput,
UnsafeAfterSideEffect,
Unknown,
}Expand description
Whether retrying an operation is safe.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Safe
The same operation can be retried safely.
RequiresIdempotency
Retry is safe only when the external system honors an idempotency key.
UnsafeAfterVisibleOutput
Visible output has been emitted, so retry may duplicate output.
UnsafeAfterSideEffect
An external side effect may already have occurred.
Unknown
Safety cannot be determined.