pub struct RunRecorder { /* private fields */ }Expand description
Cloneable event emitter bound to one run and a shared journal.
Implementations
Sourceimpl RunRecorder
impl RunRecorder
Sourcepub fn new(
journal: Arc<dyn Journal>,
run_id: RunId,
parent_run_id: Option<RunId>,
) -> Self
pub fn new( journal: Arc<dyn Journal>, run_id: RunId, parent_run_id: Option<RunId>, ) -> Self
Creates a recorder for one run.
Sourcepub fn child(&self, run_id: RunId, parent_run_id: RunId) -> Self
pub fn child(&self, run_id: RunId, parent_run_id: RunId) -> Self
Creates a recorder for a child run using the same journal.
Sourcepub fn record(
&self,
kind: RunEventKind,
caused_by: Option<EventId>,
) -> Result<RunEvent, JournalError>
pub fn record( &self, kind: RunEventKind, caused_by: Option<EventId>, ) -> Result<RunEvent, JournalError>
Emits and records one immutable event.
Errors
Returns JournalError when the journal rejects the event.